"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QPagedPaintDevice(QPaintDevice):
    """
    https://doc.qt.io/qt-6/qpagedpaintdevice.html

    **Detailed Description**

    Paged paint devices are used to generate output for printing or for formats
    like PDF. **QPdfWriter**  and **QPrinter**  inherit from it.
    """

    class PdfVersion(enum.Enum):
        PdfVersion_1_4: QPagedPaintDevice = ...
        PdfVersion_A1b: QPagedPaintDevice = ...
        PdfVersion_1_6: QPagedPaintDevice = ...

    def pageRanges(self) -> "QPageRanges":
        """
        https://doc.qt.io/qt-6/qpagedpaintdevice.html#pageRanges

        **[since 6.0] QPageRanges QPagedPaintDevice::pageRanges() const**

        Returns the page ranges associated with this device.

        This function was introduced in Qt 6.0.

        **See also** **setPageRanges** (), **QPageRanges** ,
        **QPrinter::fromPage** (), and **QPrinter::toPage** ().
        """
        ...

    def setPageRanges(self, ranges: "QPageRanges") -> None:
        """
        https://doc.qt.io/qt-6/qpagedpaintdevice.html#setPageRanges

        **[virtual, since 6.0] void QPagedPaintDevice::setPageRanges(const
        QPageRanges & ranges )**

        Sets the page ranges for this device to **ranges**.

        This function was introduced in Qt 6.0.

        **See also** **pageRanges** ().
        """
        ...

    def setPageMargins(
        self, margins: QtCore.QMarginsF, units: "QPageLayout.Unit" = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qpagedpaintdevice.html#setPageMargins

        **[virtual, since 5.3] bool QPagedPaintDevice::setPageMargins(const
        QMarginsF & margins , QPageLayout::Unit units =
        QPageLayout::Millimeter)**

        Set the page **margins** defined in the given **units**.

        You should call this before calling **QPainter::begin** (), or
        immediately before calling **newPage** () to apply the new margins to a
        new page. You should not call any painting methods between a call to
        setPageMargins() and **newPage** () as the wrong paint metrics may be
        used.

        To get the current page margins use **pageLayout** ().margins().

        Returns true if the page margins were successfully set to **margins**.

        This function was introduced in Qt 5.3.

        **See also** **pageLayout** ().
        """
        ...

    def setPageOrientation(self, orientation: "QPageLayout.Orientation") -> bool:
        """
        https://doc.qt.io/qt-6/qpagedpaintdevice.html#setPageOrientation

        **[virtual, since 5.3] bool
        QPagedPaintDevice::setPageOrientation(QPageLayout::Orientation
        orientation )**

        Sets the page **orientation**.

        The page orientation is used to define the orientation of the page size
        when obtaining the page rect.

        You should call this before calling **QPainter::begin** (), or
        immediately before calling **newPage** () to apply the new orientation
        to a new page. You should not call any painting methods between a call
        to setPageOrientation() and **newPage** () as the wrong paint metrics
        may be used.

        To get the current **QPageLayout::Orientation**  use **pageLayout**
        ().orientation().

        Returns true if the page orientation was successfully set to
        **orientation**.

        This function was introduced in Qt 5.3.

        **See also** **pageLayout** ().
        """
        ...

    def pageLayout(self) -> "QPageLayout":
        """
        https://doc.qt.io/qt-6/qpagedpaintdevice.html#pageLayout

        **[since 5.3] QPageLayout QPagedPaintDevice::pageLayout() const**

        Returns the current page layout. Use this method to access the current
        **QPageSize** , **QPageLayout::Orientation** , **QMarginsF** ,
        fullRect() and paintRect().

        Note that you cannot use the setters on the returned object, you must
        either call the individual **QPagedPaintDevice**  setters or use
        **setPageLayout** ().

        This function was introduced in Qt 5.3.

        **See also** **setPageLayout** (), **setPageSize** (),
        **setPageOrientation** (), and **setPageMargins** ().
        """
        ...

    def setPageLayout(self, pageLayout: "QPageLayout") -> bool:
        """
        https://doc.qt.io/qt-6/qpagedpaintdevice.html#setPageLayout

        **[virtual, since 5.3] bool QPagedPaintDevice::setPageLayout(const
        QPageLayout & newPageLayout )**

        Sets the page layout to **newPageLayout**.

        You should call this before calling **QPainter::begin** (), or
        immediately before calling **newPage** () to apply the new page layout
        to a new page. You should not call any painting methods between a call
        to setPageLayout() and **newPage** () as the wrong paint metrics may be
        used.

        Returns true if the page layout was successfully set to
        **newPageLayout**.

        This function was introduced in Qt 5.3.

        **See also** **pageLayout** ().
        """
        ...

    def setPageSize(self, pageSize: "QPageSize") -> bool:
        """
        https://doc.qt.io/qt-6/qpagedpaintdevice.html#setPageSize

        **[virtual, since 5.3] bool QPagedPaintDevice::setPageSize(const
        QPageSize & pageSize )**

        Sets the page size to **pageSize**.

        To get the current **QPageSize**  use **pageLayout** ().pageSize().

        You should call this before calling **QPainter::begin** (), or
        immediately before calling **newPage** () to apply the new page size to
        a new page. You should not call any painting methods between a call to
        setPageSize() and **newPage** () as the wrong paint metrics may be used.

        Returns true if the page size was successfully set to **pageSize**.

        This function was introduced in Qt 5.3.

        **See also** **pageLayout** ().
        """
        ...

    def newPage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qpagedpaintdevice.html#newPage

        **[pure virtual] bool QPagedPaintDevice::newPage()**

        Starts a new page. Returns `true` on success.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtOpenGL import *
import enum


class QOpenGLTextureBlitter(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qopengltextureblitter.html

    **Detailed Description**

    Drawing textured quads, in order to get the contents of a texture onto the
    screen, is a common operation when developing 2D user interfaces.
    QOpenGLTextureBlitter provides a convenience class to avoid repeating vertex
    data, shader sources, buffer and program management and matrix calculations.

    For example, a **QOpenGLWidget**  subclass can do the following to draw the
    contents rendered into a framebuffer at the pixel position `(x, y)`:

    void OpenGLWidget::initializeGL()
        {
            m_blitter.create();
    m_fbo = new **QOpenGLFramebufferObject** (size);
        }

        void
    OpenGLWidget::paintGL()
        {
            m_fbo->bind();
            // update
    offscreen content
            m_fbo->release();

            m_blitter.bind();
    const **QRect**  targetRect(**QPoint** (x, y), m_fbo->size());
            const
    QMatrix4x4 target = **QOpenGLTextureBlitter** ::targetTransform(targetRect,
    **QRect** (**QPoint** (0, 0), m_fbo->size()));
    m_blitter.blit(m_fbo->texture(), target, **QOpenGLTextureBlitter**
    ::OriginBottomLeft);
            m_blitter.release();
        }

    The blitter implements GLSL shaders both for GLSL 1.00 (suitable for OpenGL
    (ES) 2.x and compatibility profiles of newer OpenGL versions) and version
    150 (suitable for core profile contexts with OpenGL 3.2 and newer).
    """

    class Origin(enum.Enum):
        OriginBottomLeft: QOpenGLTextureBlitter = ...
        OriginTopLeft: QOpenGLTextureBlitter = ...

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#QOpenGLTextureBlitter

        **QOpenGLTextureBlitter::QOpenGLTextureBlitter()**

        Constructs a new QOpenGLTextureBlitter instance.

        **Note:** no graphics resources are initialized in the constructor. This
        makes it safe to place plain QOpenGLTextureBlitter members into classes
        because the actual initialization that depends on the OpenGL context
        happens only in **create** ().
        """
        ...

    @staticmethod
    def sourceTransform(
        subTexture: QtCore.QRectF,
        textureSize: QtCore.QSize,
        origin: "QOpenGLTextureBlitter.Origin",
    ) -> QtGui.QMatrix3x3:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#sourceTransform

        **[static] QMatrix3x3 QOpenGLTextureBlitter::sourceTransform(const
        QRectF & subTexture , const QSize & textureSize ,
        QOpenGLTextureBlitter::Origin origin )**

        Calculates a 3x3 matrix suitable as the input to **blit** (). This is
        used when only a part of the texture is to be used in the blit.

        **subTexture** is the desired source rectangle in pixels,
        **textureSize** is the full width and height of the texture data.
        **origin** specifies the orientation of the image data when it comes to
        the Y axis.

        **See also** **blit** () and **Origin** .
        """
        ...

    @staticmethod
    def targetTransform(
        target: QtCore.QRectF, viewport: QtCore.QRect
    ) -> QtGui.QMatrix4x4:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#targetTransform

        **[static] QMatrix4x4 QOpenGLTextureBlitter::targetTransform(const
        QRectF & target , const QRect & viewport )**

        Calculates a target transform suitable for **blit** ().

        **target** is the target rectangle in pixels. **viewport** describes the
        source dimensions and will in most cases be set to (0, 0, image width,
        image height).

        For unscaled output the size of **target** and **viewport** should
        match.

        **See also** **blit** ().
        """
        ...

    @typing.overload
    def blit(
        self,
        texture: int,
        targetTransform: QtGui.QMatrix4x4,
        sourceOrigin: "QOpenGLTextureBlitter.Origin",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#blit

        **void QOpenGLTextureBlitter::blit(GLuint texture , const QMatrix4x4 &
        targetTransform , QOpenGLTextureBlitter::Origin sourceOrigin )**

        Performs the blit with the source texture **texture**.

        **targetTransform** specifies the transformation applied. This is
        usually generated by the **targetTransform** () helper function.

        **sourceOrigin** specifies if the image data needs flipping. When
        **texture** corresponds to a texture attached to an FBO pass
        **OriginBottomLeft** . On the other hand, when **texture** is based on
        unflipped image data, pass **OriginTopLeft** . This is more efficient
        than using **QImage::mirrored** ().

        **See also** **targetTransform** (), **Origin** , and **bind** ().
        """
        ...

    @typing.overload
    def blit(
        self,
        texture: int,
        targetTransform: QtGui.QMatrix4x4,
        sourceTransform: QtGui.QMatrix3x3,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#blit-1

        **void QOpenGLTextureBlitter::blit(GLuint texture , const QMatrix4x4 &
        targetTransform , const QMatrix3x3 & sourceTransform )**

        Performs the blit with the source texture **texture**.

        **targetTransform** specifies the transformation applied. This is
        usually generated by the **targetTransform** () helper function.

        **sourceTransform** specifies the transformation applied to the source.
        This allows using only a sub-rect of the source texture. This is usually
        generated by the **sourceTransform** () helper function.

        **See also** **sourceTransform** (), **targetTransform** (), **Origin**
        , and **bind** ().
        """
        ...

    def setOpacity(self, opacity: float) -> None:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#setOpacity

        **void QOpenGLTextureBlitter::setOpacity(float opacity )**

        Changes the opacity to **opacity**. The default opacity is 1.0.

        **Note:** the blitter does not alter the blend state. It is up to the
        caller of **blit** () to ensure the correct blend settings are active.
        """
        ...

    def setRedBlueSwizzle(self, swizzle: bool) -> None:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#setRedBlueSwizzle

        **void QOpenGLTextureBlitter::setRedBlueSwizzle(bool swizzle )**

        Sets whether swizzling is enabled for the red and blue color channels to
        **swizzle**. An BGRA to RGBA conversion (occurring in the shader on the
        GPU, instead of a slow CPU-side transformation) can be useful when the
        source texture contains data from a **QImage**  with a format like
        **QImage::Format_ARGB32**  which maps to BGRA on little endian systems.

        By default the red-blue swizzle is disabled since this is what a texture
        attached to an framebuffer object or a texture based on a byte ordered
        **QImage**  format (like **QImage::Format_RGBA8888** ) needs.
        """
        ...

    def release(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#release

        **void QOpenGLTextureBlitter::release()**

        Unbinds the graphics resources used by the blitter.

        **See also** **bind** ().
        """
        ...

    def bind(self, target: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#bind

        **void QOpenGLTextureBlitter::bind(GLenum target = GL_TEXTURE_2D)**

        Binds the graphics resources used by the blitter. This must be called
        before calling **blit** (). Code modifying the OpenGL state should be
        avoided between the call to bind() and **blit** () because otherwise
        conflicts may arise.

        **target** is the texture target for the source texture and must be
        either `GL_TEXTURE_2D` or `GL_OES_EGL_image_external`.

        **See also** **release** () and **blit** ().
        """
        ...

    def supportsExternalOESTarget(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#supportsExternalOESTar
        get

        **bool QOpenGLTextureBlitter::supportsExternalOESTarget() const**

        Returns `true` when **bind** () accepts `GL_TEXTURE_EXTERNAL_OES` as its
        target argument.

        **See also** **bind** () and **blit** ().
        """
        ...

    def destroy(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#destroy

        **void QOpenGLTextureBlitter::destroy()**

        Frees all graphics resources held by the blitter. Assumes that the
        OpenGL context, or another context sharing resources with it, that was
        current on the thread when invoking **create** () is current.

        The function has no effect when the blitter is not in created state.

        **See also** **create** ().
        """
        ...

    def isCreated(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#isCreated

        **bool QOpenGLTextureBlitter::isCreated() const**

        Returns `true` if **create** () was called and succeeded. `false`
        otherwise.

        **See also** **create** () and **destroy** ().
        """
        ...

    def create(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltextureblitter.html#create

        **bool QOpenGLTextureBlitter::create()**

        Initializes the graphics resources used by the blitter.

        Returns `true` if successful, `false` if there was a failure. Failures
        can occur when there is no OpenGL context current on the current thread,
        or when shader compilation fails for some reason.

        **See also** **isCreated** () and **destroy** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *
import enum


class QLowEnergyService(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qlowenergyservice.html

    **Detailed Description**

    QLowEnergyService provides access to the details of Bluetooth Low Energy
    services. The class facilitates the discovery and publification of service
    details, permits reading and writing of the contained data and notifies
    about data changes.

    **Service Structure**

    A Bluetooth Low Energy peripheral device can contain multiple services. In
    turn each service may include further services. This class represents a
    single service of the peripheral device and is created via
    **QLowEnergyController::createServiceObject** (). The **type** () indicates
    whether this service is a primary (top-level) service or whether the service
    is part of another service. Each service may contain one or more
    characteristics and each characteristic may contain descriptors. The
    resulting structure may look like the following diagram:

    ![Structure of a generic peripheral](images/peripheral-structure.png)

    A characteristic is the principal information carrier. It has a **value** ()
    and **properties** () describing the access permissions for the value. The
    general purpose of the contained descriptor is to further define the nature
    of the characteristic. For example, it might specify how the value is meant
    to be interpreted or whether it can notify the value consumer about value
    changes.

    **Service Interaction**

    Once a service object was created for the first time, its details are yet to
    be discovered. This is indicated by its current **state** () being
    **DiscoveryRequired** . It is only possible to retrieve the **serviceUuid**
    () and **serviceName** ().

    The discovery of its included services, characteristics and descriptors is
    triggered when calling **discoverDetails** (). During the discovery the
    **state** () transitions from **DiscoveryRequired**  via
    **DiscoveringService**  to its final **ServiceDiscovered**  state. This
    transition is advertised via the **stateChanged** () signal. Once the
    details are known, all of the contained characteristics, descriptors and
    included services are known and can be read or written.

    The values of characteristics and descriptors can be retrieved via
    **QLowEnergyCharacteristic**  and **QLowEnergyDescriptor** , respectively.
    However, direct reading or writing of these attributes requires the service
    object. The **readCharacteristic** () function attempts to re-read the value
    of a characteristic. Although the initial service discovery may have
    obtained a value already this call may be required in cases where the
    characteristic value constantly changes without any notifications being
    provided. An example might be a time characteristic that provides a
    continuous value. If the read attempt is successful, the
    **characteristicRead** () signal is emitted. A failure to read the value
    triggers the **CharacteristicReadError** . The **writeCharacteristic** ()
    function attempts to write a new value to the given characteristic. If the
    write attempt is successful, the **characteristicWritten** () signal is
    emitted. A failure to write triggers the **CharacteristicWriteError** .
    Reading and writing of descriptors follows the same pattern.

    Every attempt is made to read or write the value of a descriptor or
    characteristic on the hardware. This means that meta information such as
    **QLowEnergyCharacteristic::properties** () is generally ignored when
    reading and writing. As an example, it is possible to call
    **writeCharacteristic** () despite the characteristic being read-only based
    on its meta data description. The resulting write request is forwarded to
    the connected device and it is up to the device to respond to the
    potentially invalid request. In this case the result is the emission of the
    **CharacteristicWriteError**  in response to the returned device error. This
    behavior simplifies interaction with devices which report wrong meta
    information. If it was not possible to forward the request to the remote
    device the **OperationError**  is set. A potential reason could be that the
    to-be-written characteristic object does not even belong the current
    service. In summary, the two types of errors permit a quick distinction of
    local and remote error cases.

    All requests are serialised based on First-In First-Out principle. For
    example, issuing a second write request, before the previous write request
    has finished, is delayed until the first write request has finished.

    **Note:** Currently, it is not possible to send signed write or reliable
    write requests.

    In some cases the peripheral generates value updates which the central is
    interested in receiving. In order for a characteristic to support such
    notifications it must have the **QLowEnergyCharacteristic::Notify**  or
    **QLowEnergyCharacteristic::Indicate**  property and a descriptor of type
    **QBluetoothUuid::DescriptorType::ClientCharacteristicConfiguration** .
    Provided those conditions are fulfilled notifications can be enabled as
    shown in the following code segment:

    //PreCondition: service details already discovered
    **QLowEnergyCharacteristic**  batteryLevel = service->characteristic(
    **QBluetoothUuid** ::CharacteristicType::BatteryLevel);
            if
    (!batteryLevel.isValid())
                return;
    **QLowEnergyDescriptor**  notification = batteryLevel.descriptor(
    **QBluetoothUuid** ::DescriptorType::ClientCharacteristicConfiguration);
    if (!notification.isValid())
                return;

            // establish
    hook into notifications
            connect(service,
    SIGNAL(characteristicChanged(**QLowEnergyCharacteristic** ,**QByteArray**
    )),
                    this,
    SLOT(characteristicChanged(**QLowEnergyCharacteristic** ,**QByteArray** )));
    // enable notification
            service->writeDescriptor(notification,
    **QByteArray** ::fromHex("0100"));

            // disable notification
    //service->writeDescriptor(notification, QByteArray::fromHex("0000"));
    // wait until descriptorWritten() signal is emitted
            // to confirm
    successful write

    The example shows a battery level characteristic which updates the central
    on every value change. The notifications are provided via the
    **characteristicChanged** () signal. More details about this mechanism are
    provided by the **Bluetooth Specification** .

    **Service Data Sharing**

    Each QLowEnergyService instance shares its internal states and information
    with other QLowEnergyService instance of the same service. If one instance
    initiates the discovery of the service details, all remaining instances
    automatically follow. Therefore the following snippet always works:

    QLowEnergyService *first, *second;
            **QLowEnergyController**
    control(remoteDevice);
            control.connectToDevice();

            //
    waiting for connection

            first =
    control.createServiceObject(**QBluetoothUuid**
    ::ServiceClassUuid::BatteryService);
            second =
    control.createServiceObject(**QBluetoothUuid**
    ::ServiceClassUuid::BatteryService);
            Q_ASSERT(first->state() ==
    QLowEnergyService::RemoteService);
            Q_ASSERT(first->state() ==
    second->state());

            first->discoverDetails();
    Q_ASSERT(first->state() == QLowEnergyService::RemoteServiceDiscovering);
    Q_ASSERT(first->state() == second->state());

    Other operations such as calls to **readCharacteristic** (),
    **readDescriptor** (), **writeCharacteristic** (), **writeDescriptor** () or
    the invalidation of the service due to the related **QLowEnergyController**
    disconnecting from the device are shared the same way.

    **See also** **QLowEnergyController** , **QLowEnergyCharacteristic** , and
    **QLowEnergyDescriptor** .
    """

    class WriteMode(enum.Enum):
        WriteWithResponse: QLowEnergyService = ...
        WriteWithoutResponse: QLowEnergyService = ...
        WriteSigned: QLowEnergyService = ...

    class ServiceState(enum.Enum):
        InvalidService: QLowEnergyService = ...
        DiscoveryRequired: QLowEnergyService = ...
        ServiceDiscovered: QLowEnergyService = ...
        LocalService: QLowEnergyService = ...
        RemoteService: QLowEnergyService = ...
        RemoteServiceDiscovering: QLowEnergyService = ...
        RemoteServiceDiscovered: QLowEnergyService = ...
        DiscoveringService: QLowEnergyService = ...

    class ServiceError(enum.Enum):
        NoError: QLowEnergyService = ...
        OperationError: QLowEnergyService = ...
        CharacteristicWriteError: QLowEnergyService = ...
        DescriptorWriteError: QLowEnergyService = ...
        CharacteristicReadError: QLowEnergyService = ...
        DescriptorReadError: QLowEnergyService = ...
        UnknownError: QLowEnergyService = ...

    class ServiceType(enum.Flag):
        PrimaryService: QLowEnergyService = ...
        IncludedService: QLowEnergyService = ...

    class DiscoveryMode(enum.Enum):
        FullDiscovery: QLowEnergyService = ...
        SkipValueDiscovery: QLowEnergyService = ...

    def readDescriptor(self, descriptor: QLowEnergyDescriptor) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#readDescriptor

        **[since 5.5] void QLowEnergyService::readDescriptor(const
        QLowEnergyDescriptor & descriptor )**

        Reads the value of **descriptor**. If the operation is successful, the
        **descriptorRead** () signal is emitted; otherwise the
        **DescriptorReadError**  is set.

        All descriptor and characteristic requests towards the same remote
        device are serialised. A queue is employed when issuing multiple
        requests at the same time. The queue does not eliminate duplicated read
        requests for the same descriptor.

        A descriptor can only be read if the service is in the
        **ServiceDiscovered**  state and the descriptor belongs to the service.
        If one of these conditions is not true the
        **QLowEnergyService::OperationError**  is set.

        This function was introduced in Qt 5.5.

        **See also** **descriptorRead** () and **writeDescriptor** ().
        """
        ...

    def readCharacteristic(self, characteristic: QLowEnergyCharacteristic) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#readCharacteristic

        **[since 5.5] void QLowEnergyService::readCharacteristic(const
        QLowEnergyCharacteristic & characteristic )**

        Reads the value of **characteristic**. If the operation is successful,
        the **characteristicRead** () signal is emitted; otherwise the
        **CharacteristicReadError**  is set. In general, a **characteristic** is
        readable, if its **QLowEnergyCharacteristic::Read**  property is set.

        All descriptor and characteristic requests towards the same remote
        device are serialised. A queue is employed when issuing multiple
        requests at the same time. The queue does not eliminate duplicated read
        requests for the same characteristic.

        A characteristic can only be read if the service is in the
        **ServiceDiscovered**  state and belongs to the service. If one of these
        conditions is not true the **QLowEnergyService::OperationError**  is
        set.

        **Note:** Calling this function despite
        **QLowEnergyCharacteristic::properties** () reporting a non-readable
        property always attempts to read the characteristic's value on the
        hardware. If the hardware returns with an error the
        **CharacteristicReadError**  is set.

        This function was introduced in Qt 5.5.

        **See also** **characteristicRead** () and **writeCharacteristic** ().
        """
        ...

    def writeDescriptor(
        self, descriptor: QLowEnergyDescriptor, newValue: QtCore.QByteArray
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#writeDescriptor

        **void QLowEnergyService::writeDescriptor(const QLowEnergyDescriptor &
        descriptor , const QByteArray & newValue )**

        Writes **newValue** as value for **descriptor**. The exact semantics
        depend on the role that the associated controller object is in.

        **Central role**

        A call to this function results in a write request to the remote device.
        If the operation is successful, the **descriptorWritten** () signal is
        emitted; otherwise the **DescriptorWriteError**  is emitted.

        All descriptor and characteristic requests towards the same remote
        device are serialised. A queue is employed when issuing multiple write
        requests at the same time. The queue does not eliminate duplicated write
        requests for the same descriptor. For example, if the same descriptor is
        set to the value A and immediately afterwards to B, the two write
        request are executed in the given order.

        A descriptor can only be written if this service is in the
        **ServiceDiscovered**  state, belongs to the service. If one of these
        conditions is not true the **QLowEnergyService::OperationError**  is
        set.

        **Peripheral Role**

        The value is written to the local service database. If the contents of
        **newValue** are not valid for **descriptor** , the behavior is
        unspecified.

        **See also** **descriptorWritten** () and **readDescriptor** ().
        """
        ...

    def writeCharacteristic(
        self,
        characteristic: QLowEnergyCharacteristic,
        newValue: QtCore.QByteArray,
        mode: "QLowEnergyService.WriteMode" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#writeCharacteristic

        **void QLowEnergyService::writeCharacteristic(const
        QLowEnergyCharacteristic & characteristic , const QByteArray & newValue
        , QLowEnergyService::WriteMode mode = WriteWithResponse)**

        Writes **newValue** as value for the **characteristic**. The exact
        semantics depend on the role that the associated controller object is
        in.

        **Central role**

        The call results in a write request or command to a remote peripheral.
        If the operation is successful, the **characteristicWritten** () signal
        is emitted; otherwise the **CharacteristicWriteError**  is set. Calling
        this function does not trigger the a **characteristicChanged** () signal
        unless the peripheral itself changes the value again after the current
        write request.

        The **mode** parameter determines whether the remote device should send
        a write confirmation. The to-be-written **characteristic** must support
        the relevant write mode. The characteristic's supported write modes are
        indicated by its **QLowEnergyCharacteristic::Write**  and
        **QLowEnergyCharacteristic::WriteNoResponse**  properties.

        All descriptor and characteristic write requests towards the same remote
        device are serialised. A queue is employed when issuing multiple write
        requests at the same time. The queue does not eliminate duplicated write
        requests for the same characteristic. For example, if the same
        descriptor is set to the value A and immediately afterwards to B, the
        two write request are executed in the given order.

        **Note:** Currently, it is not possible to use signed or reliable writes
        as defined by the Bluetooth specification.

        A characteristic can only be written if this service is in the
        **ServiceDiscovered**  state and belongs to the service. If one of these
        conditions is not true the **QLowEnergyService::OperationError**  is
        set.

        **Note:** Calling this function despite
        **QLowEnergyCharacteristic::properties** () reporting a non-writable
        property always attempts to write to the hardware. Similarly, a
        **WriteWithoutResponse**  is sent to the hardware too although the
        characteristic may only support **WriteWithResponse** . If the hardware
        returns with an error the **CharacteristicWriteError**  is set.

        **Peripheral role**

        The call results in the value of the characteristic getting updated in
        the local database.

        If a client is currently connected and it has enabled notifications or
        indications for the characteristic, the respective information will be
        sent. If a device has enabled notifications or indications for the
        characteristic and that device is currently not connected, but a bond
        exists between it and the local device, then the notification or
        indication will be sent on the next reconnection.

        If there is a constraint on the length of the characteristic value and
        **newValue** does not adhere to that constraint, the behavior is
        unspecified.

        **Note:** The **mode** argument is ignored in peripheral mode.

        **See also** **QLowEnergyService::characteristicWritten** () and
        **QLowEnergyService::readCharacteristic** ().
        """
        ...

    @typing.overload
    def contains(self, characteristic: QLowEnergyCharacteristic) -> bool:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#contains

        **bool QLowEnergyService::contains(const QLowEnergyCharacteristic &
        characteristic ) const**

        Returns `true` if **characteristic** belongs to this service; otherwise
        `false`.

        A characteristic belongs to a service if **characteristics** () contains
        the **characteristic**.
        """
        ...

    @typing.overload
    def contains(self, descriptor: QLowEnergyDescriptor) -> bool:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#contains-1

        **bool QLowEnergyService::contains(const QLowEnergyDescriptor &
        descriptor ) const**

        Returns `true` if **descriptor** belongs to this service; otherwise
        `false`.
        """
        ...

    def error(self) -> "QLowEnergyService.ServiceError":
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#error

        **QLowEnergyService::ServiceError QLowEnergyService::error() const**

        Returns the last occurred error or **NoError** .
        """
        ...

    def discoverDetails(self, mode: "QLowEnergyService.DiscoveryMode" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#discoverDetails

        **void
        QLowEnergyService::discoverDetails(QLowEnergyService::DiscoveryMode mode
        = FullDiscovery)**

        Initiates discovery of the service's included services, characteristics,
        and their associated descriptors.

        The discovery process is indicated via the **stateChanged** () signal.
        After creation, the service is in **DiscoveryRequired**  state. When
        calling discoverDetails() it transitions to **DiscoveringService** .
        After completion of detail discovery, it transitions to
        **ServiceDiscovered**  state. On each transition, the **stateChanged**
        () signal is emitted. Depending on the argument **mode** , a
        **FullDiscovery**  or a **SkipValueDiscovery**  is performed. In any
        case, all services and characteristics are discovered. A
        **FullDiscovery**  proceeds and reads all characteristic values and
        descriptors. A **SkipValueDiscovery**  does not read characteristic
        values and descriptors. A **SkipValueDiscovery**  has two advantages.
        First, it is faster. Second, it circumvents bugs in some devices which
        wrongly advertise characteristics or descriptors as readable but
        nevertheless do not permit reads on them. This can trigger unpredictable
        behavior. After a **SkipValueDiscovery** , it is necessary to call
        **readCharacteristic** () / **readDescriptor** () and wait for them to
        finish successfully before accessing the value of a characteristic or
        descriptor.

        The argument **mode** was introduced in Qt 6.2.

        **See also** **state** ().
        """
        ...

    def serviceName(self) -> str:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#serviceName

        **QString QLowEnergyService::serviceName() const**

        Returns the name of the service; otherwise an empty string.

        The returned name can only be retrieved if **serviceUuid** () is a
        **well-known UUID** .
        """
        ...

    def serviceUuid(self) -> QBluetoothUuid:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#serviceUuid

        **QBluetoothUuid QLowEnergyService::serviceUuid() const**

        Returns the UUID of the service; otherwise a null UUID.
        """
        ...

    def characteristics(self) -> typing.List[QLowEnergyCharacteristic]:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#characteristics

        **QList<QLowEnergyCharacteristic> QLowEnergyService::characteristics()
        const**

        Returns all characteristics associated with this `QLowEnergyService`
        instance.

        The returned list is empty if this service instance's
        **discoverDetails** () was not yet called or there are no known
        characteristics.

        **See also** **characteristic** (), **state** (), and
        **discoverDetails** ().
        """
        ...

    def characteristic(self, uuid: QBluetoothUuid) -> QLowEnergyCharacteristic:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#characteristic

        **QLowEnergyCharacteristic QLowEnergyService::characteristic(const
        QBluetoothUuid & uuid ) const**

        Returns the matching characteristic for **uuid** ; otherwise an invalid
        characteristic.

        The returned characteristic is invalid if this service instance's
        **discoverDetails** () was not yet called or there are no
        characteristics with a matching **uuid**.

        **See also** **characteristics** ().
        """
        ...

    def state(self) -> "QLowEnergyService.ServiceState":
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#state

        **QLowEnergyService::ServiceState QLowEnergyService::state() const**

        Returns the current state of the service.

        If the device's service was instantiated for the first time, the
        object's state is **DiscoveryRequired** . The state of all service
        objects which point to the same service on the peripheral device are
        always equal. This is caused by the shared nature of the internal object
        data. Therefore any service object instance created after the first one
        has a state equal to already existing instances.

        A service becomes invalid if the **QLowEnergyController**  disconnects
        from the remote device. An invalid service retains its internal state at
        the time of the disconnect event. This implies that once the service
        details are discovered they can even be retrieved from an invalid
        service. This permits scenarios where the device connection is
        established, the service details are retrieved and the device
        immediately disconnected to permit the next device to connect to the
        peripheral device.

        However, under normal circumstances the connection should remain to
        avoid repeated discovery of services and their details. The discovery
        may take a while and the client can subscribe to ongoing change
        notifications.

        **See also** **stateChanged** ().
        """
        ...

    def type(self) -> "QLowEnergyService.ServiceType":
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#type

        **QLowEnergyService::ServiceTypes QLowEnergyService::type() const**

        Returns the type of the service.

        **Note:** The type attribute cannot be relied upon until the service has
        reached the **ServiceDiscovered**  state. This field is initialised with
        **PrimaryService** .

        **Note:** On Android, it is not possible to determine whether a service
        is a primary or secondary service. Therefore all services have the
        **PrimaryService**  flag set.
        """
        ...

    def includedServices(self) -> typing.List[QBluetoothUuid]:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#includedServices

        **QList<QBluetoothUuid> QLowEnergyService::includedServices() const**

        Returns the UUIDs of all services which are included by the current
        service.

        The returned list is empty if this service instance's
        **discoverDetails** () was not yet called or there are no known
        characteristics.

        It is possible that an included service contains yet another service.
        Such second level includes have to be obtained via their relevant first
        level **QLowEnergyService**  instance. Technically, this could create a
        circular dependency.

        **QLowEnergyController::createServiceObject** () should be used to
        obtain service instances for each of the UUIDs.

        **See also** **createServiceObject** ().
        """
        ...

    @property
    def characteristicChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#characteristicChanged

        **[signal] void QLowEnergyService::characteristicChanged(const
        QLowEnergyCharacteristic & characteristic , const QByteArray & newValue
        )**

        If the associated controller object is in the **central**  role, this
        signal is emitted when the value of **characteristic** is changed by an
        event on the peripheral/device side. In that case, the signal emission
        implies that change notifications must have been activated via the
        characteristic's **ClientCharacteristicConfiguration**  descriptor prior
        to the change event on the peripheral. More details on how this might be
        done can be found further **above** .

        If the controller is in the **peripheral**  role, that is, the service
        object was created via **QLowEnergyController::addService** , the signal
        is emitted when a GATT client has written the value of the
        characteristic using a write request or command.

        The **newValue** parameter contains the updated value of the
        **characteristic**.
        """
        ...

    @property
    def characteristicRead(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#characteristicRead

        **[signal, since 5.5] void QLowEnergyService::characteristicRead(const
        QLowEnergyCharacteristic & characteristic , const QByteArray & value )**

        This signal is emitted when the read request for **characteristic**
        successfully returned its **value**. The signal might be triggered by
        calling characteristicRead(). If the read operation is not successful,
        the **error** () signal is emitted using the **CharacteristicReadError**
        flag.

        **Note:** This signal is only emitted for Central Role related use
        cases.

        This function was introduced in Qt 5.5.

        **See also** **readCharacteristic** ().
        """
        ...

    @property
    def characteristicWritten(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#characteristicWritten

        **[signal] void QLowEnergyService::characteristicWritten(const
        QLowEnergyCharacteristic & characteristic , const QByteArray & newValue
        )**

        This signal is emitted when the value of **characteristic** is
        successfully changed to **newValue**. The change must have been
        triggered by calling **writeCharacteristic** (). If the write operation
        is not successful, the **error** () signal is emitted using the
        **CharacteristicWriteError**  flag.

        The reception of the written signal can be considered as a sign that the
        target device received the to-be-written value and reports back the
        status of write request.

        **Note:** If **writeCharacteristic** () is called using the
        **WriteWithoutResponse**  mode, this signal and the **error** () are
        never emitted.

        **Note:** This signal is only emitted for Central Role related use
        cases.

        **See also** **writeCharacteristic** ().
        """
        ...

    @property
    def descriptorRead(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#descriptorRead

        **[signal, since 5.5] void QLowEnergyService::descriptorRead(const
        QLowEnergyDescriptor & descriptor , const QByteArray & value )**

        This signal is emitted when the read request for **descriptor**
        successfully returned its **value**. The signal might be triggered by
        calling descriptorRead(). If the read operation is not successful, the
        **error** () signal is emitted using the **DescriptorReadError**  flag.

        **Note:** This signal is only emitted for Central Role related use
        cases.

        This function was introduced in Qt 5.5.

        **See also** **readDescriptor** ().
        """
        ...

    @property
    def descriptorWritten(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#descriptorWritten

        **[signal] void QLowEnergyService::descriptorWritten(const
        QLowEnergyDescriptor & descriptor , const QByteArray & newValue )**

        This signal is emitted when the value of **descriptor** is successfully
        changed to **newValue**. If the associated controller object is in the
        **central**  role, the change must have been caused by calling
        **writeDescriptor** (). Otherwise, the signal is the result of a write
        request or command from a GATT client to the respective descriptor.

        **See also** **writeDescriptor** ().
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#errorOccurred

        **[signal, since 6.2] void
        QLowEnergyService::errorOccurred(QLowEnergyService::ServiceError
        newError )**

        This signal is emitted when an error occurrs. The **newError** parameter
        describes the error that occurred.

        This function was introduced in Qt 6.2.
        """
        ...

    @property
    def stateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlowenergyservice.html#stateChanged

        **[signal] void
        QLowEnergyService::stateChanged(QLowEnergyService::ServiceState newState
        )**

        This signal is emitted when the service's state changes. The
        **newState** can also be retrieved via **state** ().

        **See also** **state** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class pyqtSignal:
    signatures: typing = ...

    def __init__(self, *types: typing.Any, name: str = ...) -> None:
        ...

    @typing.overload
    def __get__(self, instance: None, owner: typing.Type["QObject"]) -> "pyqtSignal":
        ...

    @typing.overload
    def __get__(
        self, instance: "QObject", owner: typing.Type["QObject"]
    ) -> "pyqtBoundSignal":
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtWidgets
from PyQt6 import QtCore
from PyQt6.QtHelp import *


class QHelpFilterSettingsWidget(QtWidgets.QWidget):
    """
    https://doc.qt.io/qt-6/qhelpfiltersettingswidget.html

    **Detailed Description**

    The instance of QHelpFilterSettingsWidget may be a part of a preferences
    dialog. Before showing the dialog, **setAvailableComponents** () and
    **setAvailableVersions** () should be called, otherwise the filter settings
    widget will only offer a creation of empty filters, which wouldn't be
    useful. In addition, **readSettings**  should also be called to fill up the
    filter settings widget with the list of filters already stored in the filter
    engine. The creation of new filters, modifications to existing filters and
    removal of unneeded filters are handled by the widget automatically. If you
    want to store the current state of the widget and apply it to the filter
    engine e.g. after the user clicked the apply button - call **applySettings**
    ().
    """

    def __init__(self, parent: typing.Optional[QtWidgets.QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qhelpfiltersettingswidget.html#QHelpFilterSetting
        sWidget

        **QHelpFilterSettingsWidget::QHelpFilterSettingsWidget(QWidget * parent
        = nullptr)**

        Constructs a filter settings widget with **parent** as parent widget.
        """
        ...

    def applySettings(self, filterEngine: QHelpFilterEngine) -> bool:
        """
        https://doc.qt.io/qt-6/qhelpfiltersettingswidget.html#applySettings

        **bool QHelpFilterSettingsWidget::applySettings(QHelpFilterEngine *
        filterEngine ) const**

        Writes the filter settings, currently presented in this filter settings
        widget, to the **filterEngine**. The old settings stored in the filter
        engine will be overwritten. Returns `true` on success.
        """
        ...

    def readSettings(self, filterEngine: QHelpFilterEngine) -> None:
        """
        https://doc.qt.io/qt-6/qhelpfiltersettingswidget.html#readSettings

        **void QHelpFilterSettingsWidget::readSettings(const QHelpFilterEngine *
        filterEngine )**

        Reads the filter settings stored inside **filterEngine** and sets up
        this filter settings widget accordingly.
        """
        ...

    def setAvailableVersions(
        self, versions: typing.Iterable[QtCore.QVersionNumber]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qhelpfiltersettingswidget.html#setAvailableVersio
        ns

        **void QHelpFilterSettingsWidget::setAvailableVersions(const
        QList<QVersionNumber> & versions )**

        Sets the list of all available version numbers to **versions**.

        **See also** **QHelpFilterEngine::availableVersions** ().
        """
        ...

    def setAvailableComponents(self, components: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qhelpfiltersettingswidget.html#setAvailableCompon
        ents

        **void QHelpFilterSettingsWidget::setAvailableComponents(const
        QStringList & components )**

        Sets the list of all available components to **components**.

        **See also** **QHelpFilterEngine::availableComponents** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QKeyEvent(QInputEvent):
    """
    https://doc.qt.io/qt-6/qkeyevent.html

    **Detailed Description**

    Key events are sent to the widget with keyboard input focus when keys are
    pressed or released.

    A key event contains a special accept flag that indicates whether the
    receiver will handle the key event. This flag is set by default for
    **QEvent::KeyPress**  and **QEvent::KeyRelease** , so there is no need to
    call **accept** () when acting on a key event. For
    **QEvent::ShortcutOverride**  the receiver needs to explicitly accept the
    event to trigger the override. Calling **ignore** () on a key event will
    propagate it to the parent widget. The event is propagated up the parent
    widget chain until a widget accepts it or an event filter consumes it.

    The **QWidget::setEnabled** () function can be used to enable or disable
    mouse and keyboard events for a widget.

    The event handlers **QWidget::keyPressEvent** (),
    **QWidget::keyReleaseEvent** (), **QGraphicsItem::keyPressEvent** () and
    **QGraphicsItem::keyReleaseEvent** () receive key events.

    **See also** **QFocusEvent**  and **QWidget::grabKeyboard** ().
    """

    @typing.overload
    def __init__(
        self,
        type: QtCore.QEvent.Type,
        key: int,
        modifiers: QtCore.Qt.KeyboardModifier,
        nativeScanCode: int,
        nativeVirtualKey: int,
        nativeModifiers: int,
        text: str = ...,
        autorep: bool = ...,
        count: int = ...,
        device: typing.Optional["QInputDevice"] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#QKeyEvent-2

        **QKeyEvent::QKeyEvent(QEvent::Type type , int key ,
        Qt::KeyboardModifiers modifiers , const QString & text = QString(), bool
        autorep = false, quint16 count = 1)**

        Constructs a key event object.

        The **type** parameter must be **QEvent::KeyPress** ,
        **QEvent::KeyRelease** , or **QEvent::ShortcutOverride** .

        Int **key** is the code for the **Qt::Key**  that the event loop should
        listen for. If **key** is 0, the event is not a result of a known key;
        for example, it may be the result of a compose sequence or keyboard
        macro. The **modifiers** holds the keyboard modifiers, and the given
        **text** is the Unicode text that the key generated. If **autorep** is
        true, **isAutoRepeat** () will be true. **count** is the number of keys
        involved in the event.
        """
        ...

    @typing.overload
    def __init__(
        self,
        type: QtCore.QEvent.Type,
        key: int,
        modifiers: QtCore.Qt.KeyboardModifier,
        text: str = ...,
        autorep: bool = ...,
        count: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#QKeyEvent-3

        **QKeyEvent::QKeyEvent(QEvent::Type type , int key ,
        Qt::KeyboardModifiers modifiers , quint32 nativeScanCode , quint32
        nativeVirtualKey , quint32 nativeModifiers , const QString & text =
        QString(), bool autorep = false, quint16 count = 1, const QInputDevice *
        device = QInputDevice::primaryKeyboard())**

        Constructs a key event object.

        The **type** parameter must be **QEvent::KeyPress** ,
        **QEvent::KeyRelease** , or **QEvent::ShortcutOverride** .

        Int **key** is the code for the **Qt::Key**  that the event loop should
        listen for. If **key** is 0, the event is not a result of a known key;
        for example, it may be the result of a compose sequence or keyboard
        macro. The **modifiers** holds the keyboard modifiers, and the given
        **text** is the Unicode text that the key generated. If **autorep** is
        true, **isAutoRepeat** () will be true. **count** is the number of keys
        involved in the event.

        In addition to the normal key event data, also contains
        **nativeScanCode** , **nativeVirtualKey** and **nativeModifiers**. This
        extra data is used by the shortcut system, to determine which shortcuts
        to trigger.
        """
        ...

    def clone(self) -> "QKeyEvent":
        ...

    def keyCombination(self) -> QtCore.QKeyCombination:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#keyCombination

        **[since 6.0] QKeyCombination QKeyEvent::keyCombination() const**

        Returns a **QKeyCombination**  object containing both the **key** () and
        the **modifiers** () carried by this event.

        This function was introduced in Qt 6.0.
        """
        ...

    def nativeVirtualKey(self) -> int:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#nativeVirtualKey

        **quint32 QKeyEvent::nativeVirtualKey() const**

        Returns the native virtual key, or key sym of the key event. If the key
        event does not contain this data 0 is returned.

        **Note:** The native virtual key may be 0, even if the key event
        contains extended information.
        """
        ...

    def nativeScanCode(self) -> int:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#nativeScanCode

        **quint32 QKeyEvent::nativeScanCode() const**

        Returns the native scan code of the key event. If the key event does not
        contain this data 0 is returned.

        **Note:** The native scan code may be 0, even if the key event contains
        extended information.
        """
        ...

    def nativeModifiers(self) -> int:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#nativeModifiers

        **quint32 QKeyEvent::nativeModifiers() const**

        Returns the native modifiers of a key event. If the key event does not
        contain this data 0 is returned.

        **Note:** The native modifiers may be 0, even if the key event contains
        extended information.
        """
        ...

    def matches(self, key: "QKeySequence.StandardKey") -> bool:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#matches

        **bool QKeyEvent::matches(QKeySequence::StandardKey key ) const**

        Returns `true` if the key event matches the given standard **key** ;
        otherwise returns `false`.
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#count

        **int QKeyEvent::count() const**

        Returns the number of keys involved in this event. If **text** () is not
        empty, this is simply the length of the string.

        **See also** **Qt::WA_KeyCompression** .
        """
        ...

    def isAutoRepeat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#isAutoRepeat

        **bool QKeyEvent::isAutoRepeat() const**

        Returns `true` if this event comes from an auto-repeating key; returns
        `false` if it comes from an initial key press.

        Note that if the event is a multiple-key compressed event that is partly
        due to auto-repeat, this function could return either true or false
        indeterminately.
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#text

        **QString QKeyEvent::text() const**

        Returns the Unicode text that this key generated.

        Return values when modifier keys such as Shift, Control, Alt, and Meta
        are pressed differ among platforms and could return an empty string.

        **Note:****key** () will always return a valid value, independent of
        modifier keys.

        **See also** **Qt::WA_KeyCompression** .
        """
        ...

    def modifiers(self) -> QtCore.Qt.KeyboardModifier:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#modifiers

        **Qt::KeyboardModifiers QKeyEvent::modifiers() const**

        Returns the keyboard modifier flags that existed immediately after the
        event occurred.

        **Warning:** This function cannot always be trusted. The user can
        confuse it by pressing both **Shift** keys simultaneously and releasing
        one of them, for example.

        **See also** **QGuiApplication::keyboardModifiers** ().
        """
        ...

    def key(self) -> int:
        """
        https://doc.qt.io/qt-6/qkeyevent.html#key

        **int QKeyEvent::key() const**

        Returns the code of the key that was pressed or released.

        See **Qt::Key**  for the list of keyboard codes. These codes are
        independent of the underlying window system. Note that this function
        does not distinguish between capital and non-capital letters, use the
        **text** () function (returning the Unicode text the key generated) for
        this purpose.

        A value of either 0 or **Qt::Key_unknown**  means that the event is not
        the result of a known key; for example, it may be the result of a
        compose sequence, a keyboard macro, or due to key event compression.

        **See also** **Qt::WA_KeyCompression** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QLabel(QFrame):
    """
    https://doc.qt.io/qt-6/qlabel.html

    **Detailed Description**

    ![](images/windows-label.png)

    QLabel is used for displaying text or an image. No user interaction
    functionality is provided. The visual appearance of the label can be
    configured in various ways, and it can be used for specifying a focus
    mnemonic key for another widget.

    A QLabel can contain any of the following content types:

    ContentSetting
    Plain textPass a **QString**  to **setText** ().
    Rich
    textPass a **QString**  that contains rich text to **setText** ().
    A
    pixmapPass a **QPixmap**  to **setPixmap** ().
    A moviePass a **QMovie**
    to **setMovie** ().
    A numberPass an **int** or a **double** to **setNum**
    (), which converts the number to plain text.
    NothingThe same as an empty
    plain text. This is the default. Set by **clear** ().

    **Warning:** When passing a **QString**  to the constructor or calling
    **setText** (), make sure to sanitize your input, as QLabel tries to guess
    whether it displays the text as plain text or as rich text, a subset of HTML
    4 markup. You may want to call **setTextFormat** () explicitly, e.g. in case
    you expect the text to be in plain format but cannot control the text source
    (for instance when displaying data loaded from the Web).

    When the content is changed using any of these functions, any previous
    content is cleared.

    By default, labels display **left-aligned, vertically-centered**  text and
    images, where any tabs in the text to be displayed are **automatically
    expanded** . However, the look of a QLabel can be adjusted and fine-tuned in
    several ways.

    The positioning of the content within the QLabel widget area can be tuned
    with **setAlignment** () and **setIndent** (). Text content can also wrap
    lines along word boundaries with **setWordWrap** (). For example, this code
    sets up a sunken panel with a two-line text in the bottom right corner (both
    lines being flush with the right side of the label):

    **QLabel**  *label = new **QLabel** (this);
    label->setFrameStyle(**QFrame** ::Panel | **QFrame** ::Sunken);
    label->setText("first line\\nsecond line");
    label->setAlignment(Qt::AlignBottom | Qt::AlignRight);

    The properties and functions QLabel inherits from **QFrame**  can also be
    used to specify the widget frame to be used for any given label.

    A QLabel is often used as a label for an interactive widget. For this use
    QLabel provides a useful mechanism for adding an mnemonic (see
    **QKeySequence** ) that will set the keyboard focus to the other widget
    (called the QLabel's "buddy"). For example:

    **QLineEdit**  *phoneEdit = new **QLineEdit** (this);
        **QLabel**
    *phoneLabel = new **QLabel** ("&Phone:", this);
    phoneLabel->setBuddy(phoneEdit);

    In this example, keyboard focus is transferred to the label's buddy (the
    **QLineEdit** ) when the user presses Alt+P. If the buddy was a button
    (inheriting from **QAbstractButton** ), triggering the mnemonic would
    emulate a button click.

    **See also** **QLineEdit** , **QTextEdit** , **QPixmap** , **QMovie** , and
    **GUI Design Handbook: Label** .
    """

    @typing.overload
    def __init__(
        self, parent: typing.Optional[QWidget] = ..., flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#QLabel

        **QLabel::QLabel(QWidget * parent = nullptr, Qt::WindowFlags f =
        Qt::WindowFlags())**

        Constructs an empty label.

        The **parent** and widget flag **f** , arguments are passed to the
        **QFrame**  constructor.

        **See also** **setAlignment** (), **setFrameStyle** (), and
        **setIndent** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        text: str,
        parent: typing.Optional[QWidget] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#QLabel-1

        **QLabel::QLabel(const QString & text , QWidget * parent = nullptr,
        Qt::WindowFlags f = Qt::WindowFlags())**

        Constructs a label that displays the text, **text**.

        The **parent** and widget flag **f** , arguments are passed to the
        **QFrame**  constructor.

        **See also** **setText** (), **setAlignment** (), **setFrameStyle** (),
        and **setIndent** ().
        """
        ...

    def setResourceProvider(
        self, provider: typing.Callable[[QtCore.QUrl], typing.Any]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#setResourceProvider

        **[since 6.1] void QLabel::setResourceProvider(const
        QTextDocument::ResourceProvider & provider )**

        Sets the **provider** of resources for rich text of this label.

        **Note:** The label **does not** take ownership of the **provider**.

        This function was introduced in Qt 6.1.

        **See also** **resourceProvider** ().
        """
        ...

    def resourceProvider(self) -> typing.Callable[[QtCore.QUrl], typing.Any]:
        """
        https://doc.qt.io/qt-6/qlabel.html#resourceProvider

        **[since 6.1] QTextDocument::ResourceProvider QLabel::resourceProvider()
        const**

        Returns the resource provider for rich text of this label.

        This function was introduced in Qt 6.1.

        **See also** **setResourceProvider** ().
        """
        ...

    def selectionStart(self) -> int:
        """
        https://doc.qt.io/qt-6/qlabel.html#selectionStart

        **int QLabel::selectionStart() const**

        selectionStart() returns the index of the first selected character in
        the label or -1 if no text is selected.

        **Note:** The **textInteractionFlags**  set on the label need to include
        either TextSelectableByMouse or TextSelectableByKeyboard.

        **See also** **selectedText** ().
        """
        ...

    def selectedText(self) -> str:
        """
        https://doc.qt.io/qt-6/qlabel.html#selectedText-prop

        **[read-only] selectedText : const QString**

        This property holds the selected text

        If there is no selected text this property's value is an empty string.

        By default, this property contains an empty string.

        **Note:** The **textInteractionFlags**  set on the label need to include
        either TextSelectableByMouse or TextSelectableByKeyboard.

        **Access functions:**

        QString **selectedText** () const

        **See also** **hasSelectedText** ().
        """
        ...

    def hasSelectedText(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlabel.html#hasSelectedText-prop

        **[read-only] hasSelectedText : const bool**

        This property holds whether there is any text selected

        hasSelectedText() returns `true` if some or all of the text has been
        selected by the user; otherwise returns `false`.

        By default, this property is `false`.

        **Note:** The **textInteractionFlags**  set on the label need to include
        either TextSelectableByMouse or TextSelectableByKeyboard.

        **Access functions:**

        bool **hasSelectedText** () const

        **See also** **selectedText** ().
        """
        ...

    def setSelection(self, a0: int, a1: int) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#setSelection

        **void QLabel::setSelection(int start , int length )**

        Selects text from position **start** and for **length** characters.

        **Note:** The **textInteractionFlags**  set on the label need to include
        either TextSelectableByMouse or TextSelectableByKeyboard.

        **See also** **selectedText** ().
        """
        ...

    def focusNextPrevChild(self, next: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qlabel.html#focusNextPrevChild

        **[override virtual protected] bool QLabel::focusNextPrevChild(bool next
        )**

        Reimplements: **QWidget::focusNextPrevChild** (bool next).
        """
        ...

    def focusOutEvent(self, ev: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#focusOutEvent

        **[override virtual protected] void QLabel::focusOutEvent(QFocusEvent *
        ev )**

        Reimplements: **QWidget::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def focusInEvent(self, ev: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#focusInEvent

        **[override virtual protected] void QLabel::focusInEvent(QFocusEvent *
        ev )**

        Reimplements: **QWidget::focusInEvent** (QFocusEvent *event).
        """
        ...

    def contextMenuEvent(self, ev: QtGui.QContextMenuEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#contextMenuEvent

        **[override virtual protected] void
        QLabel::contextMenuEvent(QContextMenuEvent * ev )**

        Reimplements: **QWidget::contextMenuEvent** (QContextMenuEvent *event).
        """
        ...

    def mouseReleaseEvent(self, ev: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#mouseReleaseEvent

        **[override virtual protected] void
        QLabel::mouseReleaseEvent(QMouseEvent * ev )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).
        """
        ...

    def mouseMoveEvent(self, ev: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#mouseMoveEvent

        **[override virtual protected] void QLabel::mouseMoveEvent(QMouseEvent *
        ev )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).
        """
        ...

    def mousePressEvent(self, ev: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#mousePressEvent

        **[override virtual protected] void QLabel::mousePressEvent(QMouseEvent
        * ev )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def keyPressEvent(self, ev: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#keyPressEvent

        **[override virtual protected] void QLabel::keyPressEvent(QKeyEvent * ev
        )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#changeEvent

        **[override virtual protected] void QLabel::changeEvent(QEvent * ev )**

        Reimplements: **QFrame::changeEvent** (QEvent *ev).
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#paintEvent

        **[override virtual protected] void QLabel::paintEvent(QPaintEvent *)**

        Reimplements: **QFrame::paintEvent** (QPaintEvent *).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qlabel.html#event

        **[override virtual protected] bool QLabel::event(QEvent * e )**

        Reimplements: **QFrame::event** (QEvent *e).
        """
        ...

    def setText(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#text-prop

        **text : QString**

        This property holds the label's text

        If no text has been set this will return an empty string. Setting the
        text clears any previous content.

        The text will be interpreted either as plain text or as rich text,
        depending on the text format setting; see **setTextFormat** (). The
        default setting is **Qt::AutoText** ; i.e. **QLabel**  will try to auto-
        detect the format of the text set. See **Supported HTML Subset**  for
        the definition of rich text.

        If a buddy has been set, the buddy mnemonic key is updated from the new
        text.

        Note that **QLabel**  is well-suited to display small rich text
        documents, such as small documents that get their document specific
        settings (font, text color, link color) from the label's palette and
        font properties. For large documents, use **QTextEdit**  in read-only
        mode instead. **QTextEdit**  can also provide a scroll bar when
        necessary.

        **Note:** This function enables mouse tracking if **text** contains rich
        text.

        **Access functions:**

        QString **text** () const
        void **setText** (const QString &)

        **See also** **setTextFormat** (), **setBuddy** (), and **alignment** .
        """
        ...

    def setPixmap(self, a0: QtGui.QPixmap) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#pixmap-prop

        **pixmap : QPixmap**

        This property holds the label's pixmap.

        Setting the pixmap clears any previous content. The buddy shortcut, if
        any, is disabled.

        **Access functions:**

        QPixmap **pixmap** () const
        void **setPixmap** (const QPixmap &)
        """
        ...

    def setPicture(self, a0: QtGui.QPicture) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#setPicture

        **[slot] void QLabel::setPicture(const QPicture & picture )**

        Sets the label contents to **picture**. Any previous content is cleared.

        The buddy shortcut, if any, is disabled.

        **See also** **picture** () and **setBuddy** ().
        """
        ...

    @typing.overload
    def setNum(self, a0: float) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#setNum

        **[slot] void QLabel::setNum(int num )**

        Sets the label contents to plain text containing the textual
        representation of integer **num**. Any previous content is cleared. Does
        nothing if the integer's string representation is the same as the
        current contents of the label.

        The buddy shortcut, if any, is disabled.

        **See also** **setText** (), **QString::setNum** (), and **setBuddy**
        ().
        """
        ...

    @typing.overload
    def setNum(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#setNum-1

        **[slot] void QLabel::setNum(double num )**

        This is an overloaded function.

        Sets the label contents to plain text containing the textual
        representation of double **num**. Any previous content is cleared. Does
        nothing if the double's string representation is the same as the current
        contents of the label.

        The buddy shortcut, if any, is disabled.

        **See also** **setText** (), **QString::setNum** (), and **setBuddy**
        ().
        """
        ...

    def setMovie(self, movie: QtGui.QMovie) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#setMovie

        **[slot] void QLabel::setMovie(QMovie * movie )**

        Sets the label contents to **movie**. Any previous content is cleared.
        The label does NOT take ownership of the movie.

        The buddy shortcut, if any, is disabled.

        **See also** **movie** () and **setBuddy** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#clear

        **[slot] void QLabel::clear()**

        Clears any label contents.
        """
        ...

    def setOpenExternalLinks(self, open: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#openExternalLinks-prop

        **openExternalLinks : bool**

        Specifies whether **QLabel**  should automatically open links using
        **QDesktopServices::openUrl** () instead of emitting the
        **linkActivated** () signal.

        **Note:** The **textInteractionFlags**  set on the label need to include
        either LinksAccessibleByMouse or LinksAccessibleByKeyboard.

        The default value is false.

        **Access functions:**

        bool **openExternalLinks** () const
        void **setOpenExternalLinks**
        (bool **open** )

        **See also** **textInteractionFlags** ().
        """
        ...

    def textInteractionFlags(self) -> QtCore.Qt.TextInteractionFlag:
        """
        https://doc.qt.io/qt-6/qlabel.html#textInteractionFlags-prop

        **textInteractionFlags : Qt::TextInteractionFlags**

        Specifies how the label should interact with user input if it displays
        text.

        If the flags contain **Qt::LinksAccessibleByKeyboard**  the focus policy
        is also automatically set to **Qt::StrongFocus** . If
        **Qt::TextSelectableByKeyboard**  is set then the focus policy is set to
        **Qt::ClickFocus** .

        The default value is **Qt::LinksAccessibleByMouse** .

        **Access functions:**

        Qt::TextInteractionFlags **textInteractionFlags** () const
        void
        **setTextInteractionFlags** (Qt::TextInteractionFlags **flags** )
        """
        ...

    def setTextInteractionFlags(self, flags: QtCore.Qt.TextInteractionFlag) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#textInteractionFlags-prop

        **textInteractionFlags : Qt::TextInteractionFlags**

        Specifies how the label should interact with user input if it displays
        text.

        If the flags contain **Qt::LinksAccessibleByKeyboard**  the focus policy
        is also automatically set to **Qt::StrongFocus** . If
        **Qt::TextSelectableByKeyboard**  is set then the focus policy is set to
        **Qt::ClickFocus** .

        The default value is **Qt::LinksAccessibleByMouse** .

        **Access functions:**

        Qt::TextInteractionFlags **textInteractionFlags** () const
        void
        **setTextInteractionFlags** (Qt::TextInteractionFlags **flags** )
        """
        ...

    def openExternalLinks(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlabel.html#openExternalLinks-prop

        **openExternalLinks : bool**

        Specifies whether **QLabel**  should automatically open links using
        **QDesktopServices::openUrl** () instead of emitting the
        **linkActivated** () signal.

        **Note:** The **textInteractionFlags**  set on the label need to include
        either LinksAccessibleByMouse or LinksAccessibleByKeyboard.

        The default value is false.

        **Access functions:**

        bool **openExternalLinks** () const
        void **setOpenExternalLinks**
        (bool **open** )

        **See also** **textInteractionFlags** ().
        """
        ...

    def heightForWidth(self, a0: int) -> int:
        """
        https://doc.qt.io/qt-6/qlabel.html#heightForWidth

        **[override virtual] int QLabel::heightForWidth(int w ) const**

        Reimplements: **QWidget::heightForWidth(int w) const** .
        """
        ...

    def buddy(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qlabel.html#buddy

        **QWidget *QLabel::buddy() const**

        Returns this label's buddy, or nullptr if no buddy is currently set.

        **See also** **setBuddy** ().
        """
        ...

    def setBuddy(self, a0: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#setBuddy

        **void QLabel::setBuddy(QWidget * buddy )**

        Sets this label's buddy to **buddy**.

        When the user presses the shortcut key indicated by this label, the
        keyboard focus is transferred to the label's buddy widget.

        The buddy mechanism is only available for QLabels that contain text in
        which one character is prefixed with an ampersand, '&'. This character
        is set as the shortcut key. See the **QKeySequence::mnemonic** ()
        documentation for details (to display an actual ampersand, use '&&').

        In a dialog, you might create two data entry widgets and a label for
        each, and set up the geometry layout so each label is just to the left
        of its data entry widget (its "buddy"), for example:

        **QLineEdit**  *nameEdit  = new **QLineEdit** (this);
            **QLabel**
        *nameLabel = new **QLabel** ("&Name:", this);
        nameLabel->setBuddy(nameEdit);
            **QLineEdit**  *phoneEdit  = new
        **QLineEdit** (this);
            **QLabel**     *phoneLabel = new **QLabel**
        ("&Phone:", this);
            phoneLabel->setBuddy(phoneEdit);
            // (layout
        setup not shown)

        With the code above, the focus jumps to the Name field when the user
        presses Alt+N, and to the Phone field when the user presses Alt+P.

        To unset a previously set buddy, call this function with **buddy** set
        to nullptr.

        **See also** **buddy** (), **setText** (), **QShortcut** , and
        **setAlignment** ().
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlabel.html#minimumSizeHint

        **[override virtual] QSize QLabel::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlabel.html#sizeHint

        **[override virtual] QSize QLabel::sizeHint() const**

        Reimplements: **QFrame::sizeHint() const** .
        """
        ...

    def setScaledContents(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#scaledContents-prop

        **scaledContents : bool**

        This property holds whether the label will scale its contents to fill
        all available space.

        When enabled and the label shows a pixmap, it will scale the pixmap to
        fill the available space.

        This property's default is false.

        **Access functions:**

        bool **hasScaledContents** () const
        void **setScaledContents** (bool)
        """
        ...

    def hasScaledContents(self) -> bool:
        ...

    def setMargin(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#margin-prop

        **margin : int**

        This property holds the width of the margin

        The margin is the distance between the innermost pixel of the frame and
        the outermost pixel of contents.

        The default margin is 0.

        **Access functions:**

        int **margin** () const
        void **setMargin** (int)

        **See also** **indent** .
        """
        ...

    def margin(self) -> int:
        """
        https://doc.qt.io/qt-6/qlabel.html#margin-prop

        **margin : int**

        This property holds the width of the margin

        The margin is the distance between the innermost pixel of the frame and
        the outermost pixel of contents.

        The default margin is 0.

        **Access functions:**

        int **margin** () const
        void **setMargin** (int)

        **See also** **indent** .
        """
        ...

    def setIndent(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#indent-prop

        **indent : int**

        This property holds the label's text indent in pixels

        If a label displays text, the indent applies to the left edge if
        **alignment** () is **Qt::AlignLeft** , to the right edge if
        **alignment** () is **Qt::AlignRight** , to the top edge if
        **alignment** () is **Qt::AlignTop** , and to the bottom edge if
        **alignment** () is **Qt::AlignBottom** .

        If indent is negative, or if no indent has been set, the label computes
        the effective indent as follows: If **frameWidth** () is 0, the
        effective indent becomes 0. If **frameWidth** () is greater than 0, the
        effective indent becomes half the width of the "x" character of the
        widget's current **font** ().

        By default, the indent is -1, meaning that an effective indent is
        calculating in the manner described above.

        **Access functions:**

        int **indent** () const
        void **setIndent** (int)

        **See also** **alignment** , **margin** , **frameWidth** (), and
        **font** ().
        """
        ...

    def indent(self) -> int:
        """
        https://doc.qt.io/qt-6/qlabel.html#indent-prop

        **indent : int**

        This property holds the label's text indent in pixels

        If a label displays text, the indent applies to the left edge if
        **alignment** () is **Qt::AlignLeft** , to the right edge if
        **alignment** () is **Qt::AlignRight** , to the top edge if
        **alignment** () is **Qt::AlignTop** , and to the bottom edge if
        **alignment** () is **Qt::AlignBottom** .

        If indent is negative, or if no indent has been set, the label computes
        the effective indent as follows: If **frameWidth** () is 0, the
        effective indent becomes 0. If **frameWidth** () is greater than 0, the
        effective indent becomes half the width of the "x" character of the
        widget's current **font** ().

        By default, the indent is -1, meaning that an effective indent is
        calculating in the manner described above.

        **Access functions:**

        int **indent** () const
        void **setIndent** (int)

        **See also** **alignment** , **margin** , **frameWidth** (), and
        **font** ().
        """
        ...

    def wordWrap(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlabel.html#wordWrap-prop

        **wordWrap : bool**

        This property holds the label's word-wrapping policy

        If this property is `true` then label text is wrapped where necessary at
        word-breaks; otherwise it is not wrapped at all.

        By default, word wrap is disabled.

        **Access functions:**

        bool **wordWrap** () const
        void **setWordWrap** (bool **on** )

        **See also** **text** .

        **Member Function Documentation**
        """
        ...

    def setWordWrap(self, on: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#wordWrap-prop

        **wordWrap : bool**

        This property holds the label's word-wrapping policy

        If this property is `true` then label text is wrapped where necessary at
        word-breaks; otherwise it is not wrapped at all.

        By default, word wrap is disabled.

        **Access functions:**

        bool **wordWrap** () const
        void **setWordWrap** (bool **on** )

        **See also** **text** .

        **Member Function Documentation**
        """
        ...

    def setAlignment(self, a0: QtCore.Qt.AlignmentFlag) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#alignment-prop

        **alignment : Qt::Alignment**

        This property holds the alignment of the label's contents

        By default, the contents of the label are left-aligned and vertically-
        centered.

        **Access functions:**

        Qt::Alignment **alignment** () const
        void **setAlignment**
        (Qt::Alignment)

        **See also** **text** .
        """
        ...

    def alignment(self) -> QtCore.Qt.AlignmentFlag:
        """
        https://doc.qt.io/qt-6/qlabel.html#alignment-prop

        **alignment : Qt::Alignment**

        This property holds the alignment of the label's contents

        By default, the contents of the label are left-aligned and vertically-
        centered.

        **Access functions:**

        Qt::Alignment **alignment** () const
        void **setAlignment**
        (Qt::Alignment)

        **See also** **text** .
        """
        ...

    def setTextFormat(self, a0: QtCore.Qt.TextFormat) -> None:
        """
        https://doc.qt.io/qt-6/qlabel.html#textFormat-prop

        **textFormat : Qt::TextFormat**

        This property holds the label's text format

        See the **Qt::TextFormat**  enum for an explanation of the possible
        options.

        The default format is **Qt::AutoText** .

        **Access functions:**

        Qt::TextFormat **textFormat** () const
        void **setTextFormat**
        (Qt::TextFormat)

        **See also** **text** ().
        """
        ...

    def textFormat(self) -> QtCore.Qt.TextFormat:
        """
        https://doc.qt.io/qt-6/qlabel.html#textFormat-prop

        **textFormat : Qt::TextFormat**

        This property holds the label's text format

        See the **Qt::TextFormat**  enum for an explanation of the possible
        options.

        The default format is **Qt::AutoText** .

        **Access functions:**

        Qt::TextFormat **textFormat** () const
        void **setTextFormat**
        (Qt::TextFormat)

        **See also** **text** ().
        """
        ...

    def movie(self) -> QtGui.QMovie:
        """
        https://doc.qt.io/qt-6/qlabel.html#movie

        **QMovie *QLabel::movie() const**

        Returns a pointer to the label's movie, or nullptr if no movie has been
        set.

        **See also** **setMovie** ().
        """
        ...

    def picture(self) -> QtGui.QPicture:
        """
        https://doc.qt.io/qt-6/qlabel.html#picture-1

        **[since 6.0] QPicture QLabel::picture() const**

        Returns the label's picture.

        This function was introduced in Qt 6.0.
        """
        ...

    def pixmap(self) -> QtGui.QPixmap:
        """
        https://doc.qt.io/qt-6/qlabel.html#pixmap-prop

        **pixmap : QPixmap**

        This property holds the label's pixmap.

        Setting the pixmap clears any previous content. The buddy shortcut, if
        any, is disabled.

        **Access functions:**

        QPixmap **pixmap** () const
        void **setPixmap** (const QPixmap &)
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qlabel.html#text-prop

        **text : QString**

        This property holds the label's text

        If no text has been set this will return an empty string. Setting the
        text clears any previous content.

        The text will be interpreted either as plain text or as rich text,
        depending on the text format setting; see **setTextFormat** (). The
        default setting is **Qt::AutoText** ; i.e. **QLabel**  will try to auto-
        detect the format of the text set. See **Supported HTML Subset**  for
        the definition of rich text.

        If a buddy has been set, the buddy mnemonic key is updated from the new
        text.

        Note that **QLabel**  is well-suited to display small rich text
        documents, such as small documents that get their document specific
        settings (font, text color, link color) from the label's palette and
        font properties. For large documents, use **QTextEdit**  in read-only
        mode instead. **QTextEdit**  can also provide a scroll bar when
        necessary.

        **Note:** This function enables mouse tracking if **text** contains rich
        text.

        **Access functions:**

        QString **text** () const
        void **setText** (const QString &)

        **See also** **setTextFormat** (), **setBuddy** (), and **alignment** .
        """
        ...

    @property
    def linkActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlabel.html#linkActivated

        **[signal] void QLabel::linkActivated(const QString & link )**

        This signal is emitted when the user clicks a link. The URL referred to
        by the anchor is passed in **link**.

        **See also** **linkHovered** ().
        """
        ...

    @property
    def linkHovered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlabel.html#linkHovered

        **[signal] void QLabel::linkHovered(const QString & link )**

        This signal is emitted when the user hovers over a link. The URL
        referred to by the anchor is passed in **link**.

        **See also** **linkActivated** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore


class QSvgGenerator(QtGui.QPaintDevice):
    """
    https://doc.qt.io/qt-6/qsvggenerator.html

    **Detailed Description**

    This paint device represents a Scalable Vector Graphics (SVG) drawing. Like
    QPrinter, it is designed as a write-only device that generates output in a
    specific format.

    To write an SVG file, you first need to configure the output by setting the
    **fileName**  or **outputDevice**  properties. It is usually necessary to
    specify the size of the drawing by setting the **size**  property, and in
    some cases where the drawing will be included in another, the **viewBox**
    property also needs to be set.

    **QSvgGenerator**  generator;
            generator.setFileName(path);
    generator.setSize(**QSize** (200, 200));
    generator.setViewBox(**QRect** (0, 0, 200, 200));
    generator.setTitle(tr("SVG Generator Example Drawing"));
    generator.setDescription(tr("An SVG drawing created by the SVG Generator "
    "Example provided with Qt."));

    Other meta-data can be specified by setting the **title** , **description**
    and **resolution** properties.

    As with other **QPaintDevice**  subclasses, a **QPainter**  object is used
    to paint onto an instance of this class:

    **QPainter**  painter;
            painter.begin(&generator);
            ...
    painter.end();

    Painting is performed in the same way as for any other paint device.
    However, it is necessary to use the **QPainter::begin** () and **end** () to
    explicitly begin and end painting on the device.

    The **SVG Generator Example**  shows how the same painting commands can be
    used for painting a widget and writing an SVG file.

    **See also** **QSvgRenderer** , **QSvgWidget** , and **Qt SVG C++ Classes**
    .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#QSvgGenerator

        **QSvgGenerator::QSvgGenerator()**

        Constructs a new generator.
        """
        ...

    def metric(self, metric: QtGui.QPaintDevice.PaintDeviceMetric) -> int:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#metric

        **[override virtual protected] int
        QSvgGenerator::metric(QPaintDevice::PaintDeviceMetric metric ) const**

        Reimplements: **QPaintDevice::metric(QPaintDevice::PaintDeviceMetric
        metric) const** .
        """
        ...

    def paintEngine(self) -> QtGui.QPaintEngine:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#paintEngine

        **[override virtual protected] QPaintEngine
        *QSvgGenerator::paintEngine() const**

        Reimplements: **QPaintDevice::paintEngine() const** .

        Returns the paint engine used to render graphics to be converted to SVG
        format information.
        """
        ...

    @typing.overload
    def setViewBox(self, viewBox: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#viewBox

        **QRect QSvgGenerator::viewBox() const**

        Returns **viewBoxF** ().toRect().

        **See also** **setViewBox** () and **viewBoxF** ().
        """
        ...

    @typing.overload
    def setViewBox(self, viewBox: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#viewBox-prop

        **viewBox : QRectF**

        This property holds the viewBox of the generated SVG drawing

        By default this property is set to `QRect(0, 0, -1, -1)`, which
        indicates that the generator should not output the viewBox attribute of
        the `<svg>` element.

        **Note:** It is not possible to change this property while a
        **QPainter**  is active on the generator.

        **Access functions:**

        QRectF **viewBoxF** () const
        void **setViewBox** (const QRect &
        **viewBox** )
        void **setViewBox** (const QRectF & **viewBox** )

        **See also** **viewBox** (), **size** , and **resolution** .

        **Member Function Documentation**
        """
        ...

    def viewBoxF(self) -> QtCore.QRectF:
        ...

    def viewBox(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#viewBox

        **QRect QSvgGenerator::viewBox() const**

        Returns **viewBoxF** ().toRect().

        **See also** **setViewBox** () and **viewBoxF** ().
        """
        ...

    def setDescription(self, description: str) -> None:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#description-prop

        **description : QString**

        This property holds the description of the generated SVG drawing

        **Access functions:**

        QString **description** () const
        void **setDescription** (const
        QString & **description** )

        **See also** **title** .
        """
        ...

    def description(self) -> str:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#description-prop

        **description : QString**

        This property holds the description of the generated SVG drawing

        **Access functions:**

        QString **description** () const
        void **setDescription** (const
        QString & **description** )

        **See also** **title** .
        """
        ...

    def setTitle(self, title: str) -> None:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#title-prop

        **title : QString**

        This property holds the title of the generated SVG drawing

        **Access functions:**

        QString **title** () const
        void **setTitle** (const QString &
        **title** )

        **See also** **description** .
        """
        ...

    def title(self) -> str:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#title-prop

        **title : QString**

        This property holds the title of the generated SVG drawing

        **Access functions:**

        QString **title** () const
        void **setTitle** (const QString &
        **title** )

        **See also** **description** .
        """
        ...

    def setResolution(self, resolution: int) -> None:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#resolution-prop

        **resolution : int**

        This property holds the resolution of the generated output

        The resolution is specified in dots per inch, and is used to calculate
        the physical size of an SVG drawing.

        **Access functions:**

        int **resolution** () const
        void **setResolution** (int **dpi** )

        **See also** **size**  and **viewBox** .
        """
        ...

    def resolution(self) -> int:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#resolution-prop

        **resolution : int**

        This property holds the resolution of the generated output

        The resolution is specified in dots per inch, and is used to calculate
        the physical size of an SVG drawing.

        **Access functions:**

        int **resolution** () const
        void **setResolution** (int **dpi** )

        **See also** **size**  and **viewBox** .
        """
        ...

    def setOutputDevice(self, outputDevice: QtCore.QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#outputDevice-prop

        **outputDevice : QIODevice***

        This property holds the output device for the generated SVG drawing

        If both output device and file name are specified, the output device
        will have precedence.

        **Access functions:**

        QIODevice * **outputDevice** () const
        void **setOutputDevice**
        (QIODevice * **outputDevice** )

        **See also** **fileName** .
        """
        ...

    def outputDevice(self) -> QtCore.QIODevice:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#outputDevice-prop

        **outputDevice : QIODevice***

        This property holds the output device for the generated SVG drawing

        If both output device and file name are specified, the output device
        will have precedence.

        **Access functions:**

        QIODevice * **outputDevice** () const
        void **setOutputDevice**
        (QIODevice * **outputDevice** )

        **See also** **fileName** .
        """
        ...

    def setFileName(self, fileName: str) -> None:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#fileName-prop

        **fileName : QString**

        This property holds the target filename for the generated SVG drawing

        **Access functions:**

        QString **fileName** () const
        void **setFileName** (const QString &
        **fileName** )

        **See also** **outputDevice** .
        """
        ...

    def fileName(self) -> str:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#fileName-prop

        **fileName : QString**

        This property holds the target filename for the generated SVG drawing

        **Access functions:**

        QString **fileName** () const
        void **setFileName** (const QString &
        **fileName** )

        **See also** **outputDevice** .
        """
        ...

    def setSize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#size-prop

        **size : QSize**

        This property holds the size of the generated SVG drawing

        By default this property is set to `QSize(-1, -1)`, which indicates that
        the generator should not output the width and height attributes of the
        `<svg>` element.

        **Note:** It is not possible to change this property while a
        **QPainter**  is active on the generator.

        **Access functions:**

        QSize **size** () const
        void **setSize** (const QSize & **size** )

        **See also** **viewBox**  and **resolution** .
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qsvggenerator.html#size-prop

        **size : QSize**

        This property holds the size of the generated SVG drawing

        By default this property is set to `QSize(-1, -1)`, which indicates that
        the generator should not output the width and height attributes of the
        `<svg>` element.

        **Note:** It is not possible to change this property while a
        **QPainter**  is active on the generator.

        **Access functions:**

        QSize **size** () const
        void **setSize** (const QSize & **size** )

        **See also** **viewBox**  and **resolution** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QToolBox(QFrame):
    """
    https://doc.qt.io/qt-6/qtoolbox.html

    **Detailed Description**

    A toolbox is a widget that displays a column of tabs one above the other,
    with the current item displayed below the current tab. Every tab has an
    index position within the column of tabs. A tab's item is a **QWidget** .

    Each item has an **itemText** (), an optional **itemIcon** (), an optional
    **itemToolTip** (), and a **widget** (). The item's attributes can be
    changed with **setItemText** (), **setItemIcon** (), and **setItemToolTip**
    (). Each item can be enabled or disabled individually with
    **setItemEnabled** ().

    Items are added using **addItem** (), or inserted at particular positions
    using **insertItem** (). The total number of items is given by **count** ().
    Items can be deleted with delete, or removed from the toolbox with
    **removeItem** (). Combining **removeItem** () and **insertItem** () allows
    you to move items to different positions.

    The index of the current item widget is returned by **currentIndex** (), and
    set with **setCurrentIndex** (). The index of a particular item can be found
    using **indexOf** (), and the item at a given index is returned by item().

    The **currentChanged** () signal is emitted when the current item is
    changed.

    **See also** **QTabWidget** .
    """

    def __init__(
        self, parent: typing.Optional[QWidget] = ..., flags: QtCore.Qt.WindowType = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#QToolBox

        **QToolBox::QToolBox(QWidget * parent = nullptr, Qt::WindowFlags f =
        Qt::WindowFlags())**

        Constructs a new toolbox with the given **parent** and the flags, **f**.
        """
        ...

    def changeEvent(self, a0: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#changeEvent

        **[override virtual protected] void QToolBox::changeEvent(QEvent * ev
        )**

        Reimplements: **QFrame::changeEvent** (QEvent *ev).
        """
        ...

    def showEvent(self, e: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#showEvent

        **[override virtual protected] void QToolBox::showEvent(QShowEvent * e
        )**

        Reimplements: **QWidget::showEvent** (QShowEvent *event).
        """
        ...

    def event(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#event

        **[override virtual protected] bool QToolBox::event(QEvent * e )**

        Reimplements: **QFrame::event** (QEvent *e).
        """
        ...

    def itemRemoved(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#itemRemoved

        **[virtual protected] void QToolBox::itemRemoved(int index )**

        This virtual handler is called after an item was removed from position
        **index**.

        **See also** **itemInserted** ().
        """
        ...

    def itemInserted(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#itemInserted

        **[virtual protected] void QToolBox::itemInserted(int index )**

        This virtual handler is called after a new item was added or inserted at
        position **index**.

        **See also** **itemRemoved** ().
        """
        ...

    def setCurrentWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#setCurrentWidget

        **[slot] void QToolBox::setCurrentWidget(QWidget * widget )**

        Makes **widget** the current widget. The **widget** must be an item in
        this tool box.

        **See also** **addItem** (), **setCurrentIndex** (), and
        **currentWidget** ().
        """
        ...

    def setCurrentIndex(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index of the current item

        By default, for an empty toolbox, this property has a value of -1.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentChanged** ** (int **index** )

        **See also** **indexOf** () and **widget** ().

        **Member Function Documentation**
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#count-prop

        **[read-only] count : const int**

        This property holds the number of items contained in the toolbox.

        By default, this property has a value of 0.

        **Access functions:**

        int **count** () const
        """
        ...

    def indexOf(self, widget: QWidget) -> int:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#indexOf

        **int QToolBox::indexOf(const QWidget * widget ) const**

        Returns the index of **widget** , or -1 if the item does not exist.
        """
        ...

    def widget(self, index: int) -> QWidget:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#widget

        **QWidget *QToolBox::widget(int index ) const**

        Returns the widget at position **index** , or `nullptr` if there is no
        such item.
        """
        ...

    def currentWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#currentWidget

        **QWidget *QToolBox::currentWidget() const**

        Returns a pointer to the current widget, or `nullptr` if there is no
        such item.

        **See also** **currentIndex** () and **setCurrentWidget** ().
        """
        ...

    def currentIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#currentIndex-prop

        **currentIndex : int**

        This property holds the index of the current item

        By default, for an empty toolbox, this property has a value of -1.

        **Access functions:**

        int **currentIndex** () const
        void **setCurrentIndex** (int **index**
        )

        **Notifier signal:**

        void ****currentChanged** ** (int **index** )

        **See also** **indexOf** () and **widget** ().

        **Member Function Documentation**
        """
        ...

    def itemToolTip(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#itemToolTip

        **QString QToolBox::itemToolTip(int index ) const**

        Returns the tooltip of the item at position **index** , or an empty
        string if **index** is out of range.

        **See also** **setItemToolTip** ().
        """
        ...

    def setItemToolTip(self, index: int, toolTip: str) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#setItemToolTip

        **void QToolBox::setItemToolTip(int index , const QString & toolTip )**

        Sets the tooltip of the item at position **index** to **toolTip**.

        **See also** **itemToolTip** ().
        """
        ...

    def itemIcon(self, index: int) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#itemIcon

        **QIcon QToolBox::itemIcon(int index ) const**

        Returns the icon of the item at position **index** , or a null icon if
        **index** is out of range.

        **See also** **setItemIcon** ().
        """
        ...

    def setItemIcon(self, index: int, icon: QtGui.QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#setItemIcon

        **void QToolBox::setItemIcon(int index , const QIcon & icon )**

        Sets the icon of the item at position **index** to **icon**.

        **See also** **itemIcon** ().
        """
        ...

    def itemText(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#itemText

        **QString QToolBox::itemText(int index ) const**

        Returns the text of the item at position **index** , or an empty string
        if **index** is out of range.

        **See also** **setItemText** ().
        """
        ...

    def setItemText(self, index: int, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#setItemText

        **void QToolBox::setItemText(int index , const QString & text )**

        Sets the text of the item at position **index** to **text**.

        If the provided text contains an ampersand character ('&'), a mnemonic
        is automatically created for it. The character that follows the '&' will
        be used as the shortcut key. Any previous mnemonic will be overwritten,
        or cleared if no mnemonic is defined by the text. See the **QShortcut**
        documentation for details (to display an actual ampersand, use '&&').

        **See also** **itemText** ().
        """
        ...

    def isItemEnabled(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#isItemEnabled

        **bool QToolBox::isItemEnabled(int index ) const**

        Returns `true` if the item at position **index** is enabled; otherwise
        returns `false`.
        """
        ...

    def setItemEnabled(self, index: int, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#setItemEnabled

        **void QToolBox::setItemEnabled(int index , bool enabled )**

        If **enabled** is true then the item at position **index** is enabled;
        otherwise the item at position **index** is disabled.

        **See also** **isItemEnabled** ().
        """
        ...

    def removeItem(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#removeItem

        **void QToolBox::removeItem(int index )**

        Removes the item at position **index** from the toolbox. Note that the
        widget is **not** deleted.
        """
        ...

    @typing.overload
    def insertItem(self, index: int, item: QWidget, text: str) -> int:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#insertItem

        **int QToolBox::insertItem(int index , QWidget * widget , const QIcon &
        icon , const QString & text )**

        Inserts the **widget** at position **index** , or at the bottom of the
        toolbox if **index** is out of range. The new item's text is set to
        **text** , and the **icon** is displayed to the left of the **text**.
        Returns the new item's index.
        """
        ...

    @typing.overload
    def insertItem(
        self, index: int, widget: QWidget, icon: QtGui.QIcon, text: str
    ) -> int:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#insertItem-1

        **int QToolBox::insertItem(int index , QWidget * widget , const QString
        & text )**

        This is an overloaded function.

        Inserts the **widget** at position **index** , or at the bottom of the
        toolbox if **index** is out of range. The new item's text is set to
        **text**. Returns the new item's index.
        """
        ...

    @typing.overload
    def addItem(self, item: QWidget, text: str) -> int:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#addItem

        **int QToolBox::addItem(QWidget * widget , const QIcon & iconSet , const
        QString & text )**

        Adds the **widget** in a new tab at bottom of the toolbox. The new tab's
        text is set to **text** , and the **iconSet** is displayed to the left
        of the **text**. Returns the new tab's index.
        """
        ...

    @typing.overload
    def addItem(self, item: QWidget, iconSet: QtGui.QIcon, text: str) -> int:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#addItem-1

        **int QToolBox::addItem(QWidget * w , const QString & text )**

        This is an overloaded function.

        Adds the widget **w** in a new tab at bottom of the toolbox. The new
        tab's text is set to **text**. Returns the new tab's index.
        """
        ...

    @property
    def currentChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qtoolbox.html#currentChanged

        **[signal] void QToolBox::currentChanged(int index )**

        This signal is emitted when the current item is changed. The new current
        item's index is passed in **index** , or -1 if there is no current item.

        **Note:** Notifier signal for property **currentIndex** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QListWidgetItem(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qlistwidgetitem.html

    **Detailed Description**

    A QListWidgetItem represents a single item in a **QListWidget** . Each item
    can hold several pieces of information, and will display them appropriately.

    The item view convenience classes use a classic item-based interface rather
    than a pure model/view approach. For a more flexible list view widget,
    consider using the **QListView**  class with a standard model.

    List items can be inserted automatically into a list, when they are
    constructed, by specifying the list widget:

    new **QListWidgetItem** (tr("Hazel"), listWidget);

    Alternatively, list items can also be created without a parent widget, and
    later inserted into a list using **QListWidget::insertItem** ().

    List items are typically used to display **text** () and an **icon** ().
    These are set with the **setText** () and **setIcon** () functions. The
    appearance of the text can be customized with **setFont** (),
    **setForeground** (), and **setBackground** (). Text in list items can be
    aligned using the **setTextAlignment** () function. Tooltips, status tips
    and "What's This?" help can be added to list items with **setToolTip** (),
    **setStatusTip** (), and **setWhatsThis** ().

    By default, items are enabled, selectable, checkable, and can be the source
    of drag and drop operations.

    Each item's flags can be changed by calling **setFlags** () with the
    appropriate value (see **Qt::ItemFlags** ). Checkable items can be checked,
    unchecked and partially checked with the **setCheckState** () function. The
    corresponding **checkState** () function indicates the item's current check
    state.

    The **isHidden** () function can be used to determine whether the item is
    hidden. To hide an item, use **setHidden** ().

    **Subclassing**

    When subclassing QListWidgetItem to provide custom items, it is possible to
    define new types for them enabling them to be distinguished from standard
    items. For subclasses that require this feature, ensure that you call the
    base class constructor with a new type value equal to or greater than
    **UserType** , within **your** constructor.

    **See also** **QListWidget** , **Model/View Programming** ,
    **QTreeWidgetItem** , and **QTableWidgetItem** .
    """

    class ItemType(enum.IntEnum):
        Type: QListWidgetItem = ...
        UserType: QListWidgetItem = ...

    @typing.overload
    def __init__(
        self, parent: typing.Optional["QListWidget"] = ..., type: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#QListWidgetItem

        **QListWidgetItem::QListWidgetItem(QListWidget * parent = nullptr, int
        type = Type)**

        Constructs an empty list widget item of the specified **type** with the
        given **parent**. If **parent** is not specified, the item will need to
        be inserted into a list widget with **QListWidget::insertItem** ().

        This constructor inserts the item into the model of the parent that is
        passed to the constructor. If the model is sorted then the behavior of
        the insert is undetermined since the model will call the `'<'` operator
        method on the item which, at this point, is not yet constructed. To
        avoid the undetermined behavior, we recommend not to specify the parent
        and use **QListWidget::insertItem** () instead.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(
        self, text: str, parent: typing.Optional["QListWidget"] = ..., type: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#QListWidgetItem-1

        **QListWidgetItem::QListWidgetItem(const QString & text , QListWidget *
        parent = nullptr, int type = Type)**

        Constructs an empty list widget item of the specified **type** with the
        given **text** and **parent**. If the parent is not specified, the item
        will need to be inserted into a list widget with
        **QListWidget::insertItem** ().

        This constructor inserts the item into the model of the parent that is
        passed to the constructor. If the model is sorted then the behavior of
        the insert is undetermined since the model will call the `'<'` operator
        method on the item which, at this point, is not yet constructed. To
        avoid the undetermined behavior, we recommend not to specify the parent
        and use **QListWidget::insertItem** () instead.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        icon: QtGui.QIcon,
        text: str,
        parent: typing.Optional["QListWidget"] = ...,
        type: int = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#QListWidgetItem-2

        **QListWidgetItem::QListWidgetItem(const QIcon & icon , const QString &
        text , QListWidget * parent = nullptr, int type = Type)**

        Constructs an empty list widget item of the specified **type** with the
        given **icon** , **text** and **parent**. If the parent is not
        specified, the item will need to be inserted into a list widget with
        **QListWidget::insertItem** ().

        This constructor inserts the item into the model of the parent that is
        passed to the constructor. If the model is sorted then the behavior of
        the insert is undetermined since the model will call the `'<'` operator
        method on the item which, at this point, is not yet constructed. To
        avoid the undetermined behavior, we recommend not to specify the parent
        and use **QListWidget::insertItem** () instead.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QListWidgetItem") -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#QListWidgetItem-3

        **QListWidgetItem::QListWidgetItem(const QListWidgetItem & other )**

        Constructs a copy of **other**. Note that **type** () and **listWidget**
        () are not copied.

        This function is useful when reimplementing **clone** ().

        **See also** **data** () and **flags** ().
        """
        ...

    def isHidden(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#isHidden

        **bool QListWidgetItem::isHidden() const**

        Returns `true` if the item is hidden; otherwise returns `false`.

        **See also** **setHidden** ().
        """
        ...

    def setHidden(self, ahide: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setHidden

        **void QListWidgetItem::setHidden(bool hide )**

        Hides the item if **hide** is true; otherwise shows the item.

        **See also** **isHidden** ().
        """
        ...

    def isSelected(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#isSelected

        **bool QListWidgetItem::isSelected() const**

        Returns `true` if the item is selected; otherwise returns `false`.

        **See also** **setSelected** ().
        """
        ...

    def setSelected(self, aselect: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setSelected

        **void QListWidgetItem::setSelected(bool select )**

        Sets the selected state of the item to **select**.

        **See also** **isSelected** ().
        """
        ...

    def setForeground(
        self,
        brush: typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setForeground

        **void QListWidgetItem::setForeground(const QBrush & brush )**

        Sets the foreground brush of the list item to the given **brush**.
        Setting a default-constructed brush will let the view use the default
        color from the style.

        **See also** **foreground** () and **setBackground** ().
        """
        ...

    def foreground(self) -> QtGui.QBrush:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#foreground

        **QBrush QListWidgetItem::foreground() const**

        Returns the brush used to display the list item's foreground (e.g.
        text).

        **See also** **setForeground** () and **background** ().
        """
        ...

    def setBackground(
        self,
        brush: typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setBackground

        **void QListWidgetItem::setBackground(const QBrush & brush )**

        Sets the background brush of the list item to the given **brush**.
        Setting a default-constructed brush will let the view use the default
        color from the style.

        **See also** **background** () and **setForeground** ().
        """
        ...

    def background(self) -> QtGui.QBrush:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#background

        **QBrush QListWidgetItem::background() const**

        Returns the brush used to display the list item's background.

        **See also** **setBackground** () and **foreground** ().
        """
        ...

    def setFont(self, afont: QtGui.QFont) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setFont

        **void QListWidgetItem::setFont(const QFont & font )**

        Sets the font used when painting the item to the given **font**.

        **See also** **font** ().
        """
        ...

    def setWhatsThis(self, awhatsThis: str) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setWhatsThis

        **void QListWidgetItem::setWhatsThis(const QString & whatsThis )**

        Sets the "What's This?" help for the list item to the text specified by
        **whatsThis**.

        **See also** **whatsThis** (), **setStatusTip** (), and **setToolTip**
        ().
        """
        ...

    def setToolTip(self, atoolTip: str) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setToolTip

        **void QListWidgetItem::setToolTip(const QString & toolTip )**

        Sets the tooltip for the list item to the text specified by **toolTip**.

        **See also** **toolTip** (), **setStatusTip** (), and **setWhatsThis**
        ().
        """
        ...

    def setStatusTip(self, astatusTip: str) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setStatusTip

        **void QListWidgetItem::setStatusTip(const QString & statusTip )**

        Sets the status tip for the list item to the text specified by
        **statusTip**. **QListWidget**  mouseTracking needs to be enabled for
        this feature to work.

        **See also** **statusTip** (), **setToolTip** (), **setWhatsThis** (),
        and **QWidget::setMouseTracking** ().
        """
        ...

    def setIcon(self, aicon: QtGui.QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setIcon

        **void QListWidgetItem::setIcon(const QIcon & icon )**

        Sets the icon for the list item to the given **icon**.

        **See also** **icon** (), **text** (), and **iconSize** .
        """
        ...

    def setText(self, atext: str) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setText

        **void QListWidgetItem::setText(const QString & text )**

        Sets the text for the list widget item's to the given **text**.

        **See also** **text** ().
        """
        ...

    def setFlags(self, aflags: QtCore.Qt.ItemFlag) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setFlags

        **void QListWidgetItem::setFlags(Qt::ItemFlags flags )**

        Sets the item flags for the list item to **flags**.

        **See also** **flags** () and **Qt::ItemFlags** .
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#type

        **int QListWidgetItem::type() const**

        Returns the type passed to the **QListWidgetItem**  constructor.
        """
        ...

    def write(self, out: QtCore.QDataStream) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#write

        **[virtual] void QListWidgetItem::write(QDataStream & out ) const**

        Writes the item to stream **out**.

        **See also** **read** ().
        """
        ...

    def read(self, in_: QtCore.QDataStream) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#read

        **[virtual] void QListWidgetItem::read(QDataStream & in )**

        Reads the item from stream **in**.

        **See also** **write** ().
        """
        ...

    def setData(self, role: int, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setData

        **[virtual] void QListWidgetItem::setData(int role , const QVariant &
        value )**

        Sets the data for a given **role** to the given **value**. Reimplement
        this function if you need extra roles or special behavior for certain
        roles.

        **Note:** The default implementation treats **Qt::EditRole**  and
        **Qt::DisplayRole**  as referring to the same data.

        **See also** **Qt::ItemDataRole**  and **data** ().
        """
        ...

    def data(self, role: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#data

        **[virtual] QVariant QListWidgetItem::data(int role ) const**

        Returns the item's data for a given **role**. Reimplement this function
        if you need extra roles or special behavior for certain roles.

        **See also** **Qt::ItemDataRole**  and **setData** ().
        """
        ...

    def setSizeHint(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setSizeHint

        **void QListWidgetItem::setSizeHint(const QSize & size )**

        Sets the size hint for the list item to be **size**. If no size hint is
        set or **size** is invalid, the item delegate will compute the size hint
        based on the item data.

        **See also** **sizeHint** ().
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#sizeHint

        **QSize QListWidgetItem::sizeHint() const**

        Returns the size hint set for the list item.

        **See also** **setSizeHint** ().
        """
        ...

    def setCheckState(self, state: QtCore.Qt.CheckState) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setCheckState

        **void QListWidgetItem::setCheckState(Qt::CheckState state )**

        Sets the check state of the list item to **state**.

        **See also** **checkState** ().
        """
        ...

    def checkState(self) -> QtCore.Qt.CheckState:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#checkState

        **Qt::CheckState QListWidgetItem::checkState() const**

        Returns the checked state of the list item (see **Qt::CheckState** ).

        **See also** **setCheckState** () and **flags** ().
        """
        ...

    def setTextAlignment(self, alignment: int) -> None:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#setTextAlignment

        **void QListWidgetItem::setTextAlignment(int alignment )**

        Sets the list item's text alignment to **alignment**.

        **See also** **textAlignment** () and **Qt::AlignmentFlag** .
        """
        ...

    def textAlignment(self) -> int:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#textAlignment

        **int QListWidgetItem::textAlignment() const**

        Returns the text alignment for the list item.

        **See also** **setTextAlignment** () and **Qt::AlignmentFlag** .
        """
        ...

    def font(self) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#font

        **QFont QListWidgetItem::font() const**

        Returns the font used to display this list item's text.

        **See also** **setFont** ().
        """
        ...

    def whatsThis(self) -> str:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#whatsThis

        **QString QListWidgetItem::whatsThis() const**

        Returns the list item's "What's This?" help text.

        **See also** **setWhatsThis** (), **statusTip** (), and **toolTip** ().
        """
        ...

    def toolTip(self) -> str:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#toolTip

        **QString QListWidgetItem::toolTip() const**

        Returns the list item's tooltip.

        **See also** **setToolTip** (), **statusTip** (), and **whatsThis** ().
        """
        ...

    def statusTip(self) -> str:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#statusTip

        **QString QListWidgetItem::statusTip() const**

        Returns the list item's status tip.

        **See also** **setStatusTip** ().
        """
        ...

    def icon(self) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#icon

        **QIcon QListWidgetItem::icon() const**

        Returns the list item's icon.

        **See also** **setIcon** () and **iconSize** .
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#text

        **QString QListWidgetItem::text() const**

        Returns the list item's text.

        **See also** **setText** ().
        """
        ...

    def flags(self) -> QtCore.Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#flags

        **Qt::ItemFlags QListWidgetItem::flags() const**

        Returns the item flags for this item (see **Qt::ItemFlags** ).

        **See also** **setFlags** ().
        """
        ...

    def listWidget(self) -> "QListWidget":
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#listWidget

        **QListWidget *QListWidgetItem::listWidget() const**

        Returns the list widget containing the item.
        """
        ...

    def clone(self) -> "QListWidgetItem":
        """
        https://doc.qt.io/qt-6/qlistwidgetitem.html#clone

        **[virtual] QListWidgetItem *QListWidgetItem::clone() const**

        Creates an exact copy of the item.
        """
        ...
